; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.

[ReMap]
a = a
b = b
c = c
x = x
y = y
z = z
s = s

[Defaults]
Command.Time = 15
Command.Buffer.Time = 3

[Command]
name = "Hazan Tenshou Kyaku"
command = ~30$B, DF, DB, UF, a+b
time = 60

[Command]
name = "Hazan Tenshou Kyaku"
command = ~D, B, D, F, a+b
time = 30

[Command]
name = "Houyoku Sen"
command = ~D, F, D, F, a
time = 20

[Command]
name = "Houyoku Sen"
command = ~D, F, D, F, ~a
time = 20

[Command]
name = "Houyoku Sen"
command = ~D, F, D, F, b
time = 20

[Command]
name = "Houyoku Sen"
command = ~D, F, D, F, ~b
time = 20

[Command]
name = "Kikou Shou"
command = ~D, F, D, F, x
time = 20

[Command]
name = "Kikou Shou"
command = ~D, F, D, F, ~x
time = 20

[Command]
name = "Kikou Shou"
command = ~D, F, D, F, y
time = 20

[Command]
name = "Kikou Shou"
command = ~D, F, D, F, ~y
time = 20

[Command]
name = "Sen'en Shuu a"
command = ~F, D, B, a

[Command]
name = "Sen'en Shuu a"
command = ~F, D, B, ~a

[Command]
name = "Sen'en Shuu b"
command = ~F, D, B, b

[Command]
name = "Sen'en Shuu b"
command = ~F, D, B, ~b

[Command]
name = "Tenshin Enbu"
command = ~F, D, B, x

[Command]
name = "Tenshin Enbu"
command = ~F, D, B, ~x

[Command]
name = "Tenshin Enbu"
command = ~F, D, B, y

[Command]
name = "Tenshin Enbu"
command = ~F, D, B, ~y

[Command]
name = "Kikou Ken x"
command = ~B, D, F, x

[Command]
name = "Kikou Ken x"
command = ~B, D, F, ~x

[Command]
name = "Kikou Ken y"
command = ~B, D, F, y

[Command]
name = "Kikou Ken y"
command = ~B, D, F, ~y

[Command]
name = "Spinning Bird Kick a"
command = ~30$D, $U, a

[Command]
name = "Spinning Bird Kick a"
command = ~30$D, $U, ~a

[Command]
name = "Spinning Bird Kick b"
command = ~30$D, $U, b

[Command]
name = "Spinning Bird Kick b"
command = ~30$D, $U, ~b

[Command]
name = "Tenshou Kyaku a"
command = ~F, D, DF, a

[Command]
name = "Tenshou Kyaku a"
command = ~F, D, DF, ~a

[Command]
name = "Tenshou Kyaku b"
command = ~F, D, DF, b

[Command]
name = "Tenshou Kyaku b"
command = ~F, D, DF, ~b

[Command]
name = "Hyakuretsu Kyaku a"
command = ~a, a, a, a
time = 40
buffer.time = 6

[Command]
name = "Hyakuretsu Kyaku a"
command = a, a, a, ~a
time = 40
buffer.time = 6

[Command]
name = "Hyakuretsu Kyaku b"
command = ~b, b, b, b
time = 40
buffer.time = 5

[Command]
name = "Hyakuretsu Kyaku b"
command = b, b, b, ~b
time = 40
buffer.time = 5

[Command]
name = "2a"
command = ~a, a
time = 20
buffer.time = 7

[Command]
name = "2a"
command = a, ~a
time = 20
buffer.time = 7

[Command]
name = "2b"
command = ~b, b
buffer.time = 6

[Command]
name = "2b"
command = b, ~b
buffer.time = 6

[Command]
name = "FF"; Required
command = F, F
time = 10

[Command]
name = "BB"; Required
command = B, B
time = 10

[Command]
name = "High Jump"
command = $D, $U
time = 8

[Command]
name = "recovery"; Required
command = a+x
time = 1

[Command]
name = "Kirin Shuu"
command = a+x
time = 1

[Command]
name = "Guard Cancel Frontstep"
command = a+y
time = 1

[Command]
name = "Guard Cancel Attack"
command = b+y
time = 1

[Command]
name = "recovery"; Required
command = x+y
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[StateDef -1]
[State -1, Hazan Tenshou Kyaku]
type = ChangeState
triggerall = !var(58) && life <= lifemax / 2 && command = "Hazan Tenshou Kyaku"
trigger1 = statetype != A && (ctrl || stateno = 40 || stateno = 100)
trigger2 = var(5)
trigger3 = var(7)
value = 3200

[State -1, Houyoku Sen]
type = ChangeState
triggerall = (power >= 1000 || var(6) = 1) && command = "Houyoku Sen"
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
trigger3 = var(7)
value = 3100

[State -1, Kikou Shou]
type = ChangeState
triggerall = (power >= 1000 || var(6) = 1) && command = "Kikou Shou"
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
trigger3 = var(7)
value = 3000

[State -1, Sen'en Shuu];'
type = ChangeState
triggerall = command = "Sen'en Shuu a" || command = "Sen'en Shuu b"
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
trigger3 = var(7) && (stateno != [1400, 1410])
value = ifelse(command = "Sen'en Shuu a", 1400, 1410)

[State -1, Tenshin Enbu]
type = ChangeState
triggerall = command = "Tenshin Enbu"
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
value = 1500

[State -1, Kikou Ken]
type = ChangeState
triggerall = (command = "Kikou Ken x" || command = "Kikou Ken y") && !numhelper(1100)
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
trigger3 = var(7) && (stateno != [1100, 1110])
value = ifelse(command = "Kikou Ken x", 1100, 1110)

[State -1, Spinning Bird Kick]
type = ChangeState
triggerall = command = "Spinning Bird Kick a" || command = "Spinning Bird Kick b"
trigger1 = statetype != a && (ctrl || stateno = 40 || stateno = 100)
trigger2 = var(5)
trigger3 = var(7) && (stateno != [1200, 1210])
value = ifelse(command = "Spinning Bird Kick a", 1200, 1210)

[State -1, Tenshou Kyaku]
type = ChangeState
triggerall = command = "Tenshou Kyaku a" || command = "Tenshou Kyaku b"
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
trigger3 = var(7) && (stateno != [1300, 1310])
value = ifelse(command = "Tenshou Kyaku a", 1300, 1310)

[State -1, Hyakuretsu Kyaku]
type = ChangeState
triggerall = command = "Hyakuretsu Kyaku a" || command = "Hyakuretsu Kyaku b"
trigger1 = statetype != a && (ctrl || stateno = 100)
trigger2 = var(5)
trigger3 = var(7)
value = ifelse(command = "Hyakuretsu Kyaku a", 1000, 1010)
anim = 1000

[State -1, Run Fwd]
type = ChangeState
triggerall = command = "FF"
trigger1 = statetype = S && ctrl
value = 100

[State -1, Run Back]
type = ChangeState
triggerall = command = "BB"
trigger1 = statetype = S && ctrl
value = 105

[state -1, Sankaku Tobi]
type = changestate
triggerall = command = "holdup" && statetype = a && (ctrl || stateno = 105)
trigger1 = command = "holdfwd" && Vel X <= 0 && !backedgebodydist
trigger2 = command = "holdback" && Vel X >= 0 && !frontedgebodydist
value = 40

[State -1, Guard Cancel Frontstep]
type = ChangeState
triggerall = (stateno = 150 || stateno = 152) && alive
trigger1 = (power >= 606 || var(6) = 1) && command = "Guard Cancel Frontstep"
trigger2 = (power >= 212 || var(6) = 1) && command = "FF"
value = 160
ignorehitpause = 1

[State -1, Guard Cancel Attack]
type = ChangeState
triggerall = command = "Guard Cancel Attack" && (power >= 1000 || var(6) = 1) && alive
trigger1 = stateno = 150 || stateno = 152
value = 165
ignorehitpause = 1

[State -1, Kirin Shuu or Koshuu Tou]
type = ChangeState
triggerall = command = "Kirin Shuu" || command = "Guard Cancel Attack"
trigger1 = statetype = s && (ctrl || stateno = 100)
value = ifelse(command = "Kirin Shuu", 800, 850)

[State -1, weak punch]
Type = ChangeState
TriggerAll = command = "x" && command != "holddown"
Trigger1 = stateType = S && (Ctrl || stateno = 100)
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 300 && animelem = 2, > 2
trigger4 = stateno = 400 && animelem = 3, > 0
trigger5 = stateno = 430 && animelem = 3, > 0
value = ifelse(p2bodydist x > 20, 300, 200)

[State -1, strong punch]
Type = ChangeState
TriggerAll = command = "y" && command != "holddown"
Trigger1 = stateType = S && (Ctrl || stateno = 100)
value = ifelse(p2bodydist x > 35, 310, 210)

[State -1, Kakusen Kyaku]
Type = ChangeState
TriggerAll = Command = "a" && Command != "holddown" && command = "holdfwd"
Trigger1 = StateType = s && (Ctrl || stateno = 100)
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 210 && animelem = 3, > 0
trigger4 = stateno = 230 && animelem = 2, > 0
trigger5 = stateno = 240 && animelem = 4, > 0
trigger6 = stateno = 350 && animelem = 9, > 0
trigger7 = stateno = 430 && animelem = 3, > 0
trigger8 = stateno = 530 && animelem = 9, > 1
value = 320

[State -1, weak kick]
Type = ChangeState
TriggerAll = command = "a" && command != "holddown"
Trigger1 = stateType = S && (Ctrl || stateno = 100)
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 300 && animelem = 2, > 2
trigger4 = stateno = 400 && animelem = 3, > 0
trigger5 = stateno = 430 && animelem = 3, > 0
value = ifelse(p2bodydist x > 20, 330, 230)

[State -1, Kakusen Rakushuu]
Type = ChangeState
TriggerAll = Command = "b" && Command != "holddown" && command = "holdfwd"
Trigger1 = StateType = s && (Ctrl || stateno = 100)
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 210 && animelem = 3, > 0
trigger4 = stateno = 230 && animelem = 2, > 0
trigger5 = stateno = 240 && animelem = 4, > 0
trigger6 = stateno = 320 && animelem = 9, > 0
trigger7 = stateno = 430 && animelem = 3, > 0
trigger8 = stateno = 530 && animelem = 9, > 1
value = 350

[State -1, strong kick]
Type = ChangeState
TriggerAll = command = "b" && command != "holddown"
Trigger1 = stateType = S && (Ctrl || stateno = 100)
value = ifelse(p2bodydist x > 17, 340, 240)

[State -1, c weak punch]
Type = ChangeState
TriggerAll = Command = "x" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 300 && animelem = 2, > 2
trigger4 = stateno = 400 && animelem = 3, > 0
trigger5 = stateno = 430 && animelem = 3, > 0
value = 400

[State -1, c strong punch]
Type = ChangeState
TriggerAll = Command = "y" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
value = 410

[State -1, Zensou Sentai]
Type = ChangeState
TriggerAll = Command = "a" && Command = "holddown" && command = "holdfwd"
Trigger1 = StateType = C && Ctrl
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 210 && animelem = 3, > 0
trigger4 = stateno = 230 && animelem = 2, > 0
trigger5 = stateno = 240 && animelem = 4, > 0
trigger6 = stateno = 430 && animelem = 3, > 0
value = 530

[State -1, c weak kick]
Type = ChangeState
TriggerAll = Command = "a" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 300 && animelem = 2, > 2
trigger4 = stateno = 400 && animelem = 3, > 0
trigger5 = stateno = 430 && animelem = 3, > 0
value = 430

[State -1, Kaku Kyaku Raku]
Type = ChangeState
TriggerAll = Command = "b" && Command = "holddown" && command = "holdfwd"
Trigger1 = StateType = C && Ctrl
trigger2 = stateno = 200 && animelem = 4, > 0
trigger3 = stateno = 210 && animelem = 3, > 0
trigger4 = stateno = 230 && animelem = 2, > 0
trigger5 = stateno = 240 && animelem = 4, > 0
trigger6 = stateno = 430 && animelem = 3, > 0
value = 760

[State -1, c strong kick]
Type = ChangeState
TriggerAll = Command = "b" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
value = 440

[State -1, a weak punch]
Type = ChangeState
TriggerAll = Command = "x"
Trigger1 = StateType = A && Ctrl
Value = ifelse(vel x || stateno = 750, 700, 600)

[State -1, a strong punch]
Type = ChangeState
TriggerAll = Command = "y"
Trigger1 = StateType = A && Ctrl
trigger2 = stateno = 710 && animelem = 3, > 0
Value = ifelse(stateno = 710, 720, ifelse(vel x || stateno = 750, 710, 610))

[State -1, Yousou Kyaku]
Type = ChangeState
TriggerAll = command = "holddown" && Command = "a"
Trigger1 = StateType = A && Ctrl
trigger2 = stateno = 710 && animelem = 3, > 0 && movecontact
Value = 750

[State -1, a weak kick]
Type = ChangeState
TriggerAll = Command = "a"
Trigger1 = StateType = A && Ctrl
Value = ifelse(vel x || stateno = 750, 730, 630)

[State -1, a strong kick]
Type = ChangeState
TriggerAll = Command = "b"
Trigger1 = StateType = A && Ctrl
Value = ifelse(vel x || stateno = 750, 740, 640)

[State -1, Taunt]
type = ChangeState
triggerall = command = "start"
trigger1 = statetype = S && (ctrl || stateno = 100)
value = 195
